#!/bin/bash
# Build NGINX and modules on Heroku.
# This program is designed to run in a web dyno provided by Heroku.
# We would like to build an NGINX binary for the builpack on the
# exact machine in which the binary will run.
# Our motivation for running in a web dyno is that we need a way to
# download the binary once it is built so we can vendor it in the buildpack.
#
# Once the dyno has is 'up' you can open your browser and navigate
# this dyno's directory structure to download the nginx binary.

NGINX_VERSION=${NGINX_VERSION-1.8.1}
PCRE_VERSION=${PCRE_VERSION-8.38}
HEADERS_MORE_VERSION=${HEADERS_MORE_VERSION-0.29}
ZLIB_VERSION=${ZLIB_VERSION-1.2.8}

nginx_tarball_url=http://nginx.org/download/nginx-${NGINX_VERSION}.tar.gz
pcre_tarball_url=ftp://ftp.csx.cam.ac.uk/pub/software/programming/pcre/pcre-${PCRE_VERSION}.tar.bz2
zlib_tarball_url=http://zlib.net/zlib-${ZLIB_VERSION}.tar.gz
headers_more_nginx_module_url=https://github.com/agentzh/headers-more-nginx-module/archive/v${HEADERS_MORE_VERSION}.tar.gz
sigsci_ngx_bundle_url=https://dl.signalsciences.net/nginx-lua/sigsci-ngx-bundle_latest.tar.gz

temp_dir=$(mktemp -d /tmp/nginx.XXXXXXXXXX)

echo "Serving files from /tmp on $PORT"
cd /tmp
python -m SimpleHTTPServer $PORT &

cd $temp_dir
echo "Temp dir: $temp_dir"

echo "Downloading $nginx_tarball_url"
curl -L $nginx_tarball_url | tar xzv

set -x 

echo "Downloading $pcre_tarball_url"
(cd nginx-${NGINX_VERSION} && curl -L $pcre_tarball_url | tar xvj )

echo "Downloading $zlib_tarball_url"
(cd nginx-${NGINX_VERSION} && curl -L $zlib_tarball_url | tar xvz )

echo "Downloading $headers_more_nginx_module_url"
(cd nginx-${NGINX_VERSION} && curl -L $headers_more_nginx_module_url | tar xvz )

echo "Downloading $sigsci_ngx_bundle_url"
(cd nginx-${NGINX_VERSION} && curl -L $sigsci_ngx_bundle_url | tar xvz )

set -x

(
	cd nginx-${NGINX_VERSION}

        # bootstrap luajit build
        pushd sigsci-ngx-bundle
        ./bootstrap.sh 
        popd

        export LUAJIT_LIB="${temp_dir}/nginx-${NGINX_VERSION}/sigsci-ngx-bundle/LuaJIT-2.0.4/src"
        export LUAJIT_INC="${temp_dir}/nginx-${NGINX_VERSION}/sigsci-ngx-bundle/LuaJIT-2.0.4/src"

	./configure \
		--with-pcre=pcre-${PCRE_VERSION} \
		--with-zlib=zlib-${ZLIB_VERSION} \
		--prefix=/tmp/nginx \
		--add-module=${temp_dir}/nginx-${NGINX_VERSION}/headers-more-nginx-module-${HEADERS_MORE_VERSION} \
                --add-module=${temp_dir}/nginx-${NGINX_VERSION}/sigsci-ngx-bundle/ngx_devel_kit-0.2.19 \
                --add-module=${temp_dir}/nginx-${NGINX_VERSION}/sigsci-ngx-bundle/lua-nginx-module-0.9.16
	make install
)

while true
do
	sleep 1
	echo "."
done
